@@ -18,165 +18,156 @@
 
 #' Daemons (Set Persistent Processes)
 #'
-#' Set \sQuote{daemons} or persistent background processes to receive
-#' \code{\link{mirai}} requests. Specify \sQuote{n} to create daemons on the
-#' local machine. Specify \sQuote{url} to receive connections from remote
-#' daemons (for distributed computing across the network). Specify
-#' \sQuote{remote} to optionally launch remote daemons via a remote
-#' configuration. By default, dispatcher ensures optimal scheduling.
+#' Set daemons, or persistent background processes, to receive [mirai()]
+#' requests. Specify `n` to create daemons on the local machine. Specify `url`
+#' to receive connections from remote daemons (for distributed computing across
+#' the network). Specify `remote` to optionally launch remote daemons via a
+#' remote configuration. Dispatcher (enabled by default) ensures optimal
+#' scheduling.
 #'
-#' Use \code{daemons(0)} to reset daemon connections:
+#' Use `daemons(0)` to reset daemon connections:
 #' \itemize{
 #'   \item All connected daemons and/or dispatchers exit automatically.
 #'   \item \pkg{mirai} reverts to the default behaviour of creating a new
 #'   background process for each request.
-#'   \item Any unresolved \sQuote{mirai} will return an \sQuote{errorValue} 19
-#'   (Connection reset) after a reset.
-#'   \item Daemons must be reset before calling \code{daemons} with revised
+#'   \item Any unresolved 'mirai' will return an 'errorValue' 19 (Connection
+#'   reset) after a reset.
+#'   \item Daemons must be reset before calling `daemons()` with revised
 #'   settings for a compute profile. Daemons may be added at any time by using
-#'   \code{\link{launch_local}} or \code{\link{launch_remote}} without needing
-#'   to revise daemons settings.
+#'   [launch_local()] or [launch_remote()] without needing to revise daemons
+#'   settings.
 #' }
 #'
 #' If the host session ends, all connected dispatcher and daemon processes
 #' automatically exit as soon as their connections are dropped (unless the
-#' daemons were started with \code{autoexit = FALSE}). If a daemon is processing
+#' daemons were started with `autoexit = FALSE`). If a daemon is processing
 #' a task, it will exit as soon as the task is complete.
 #'
-#' To reset persistent daemons started with \code{autoexit = FALSE}, use
-#' \code{daemons(NULL)} instead, which also sends exit signals to all connected
+#' To reset persistent daemons started with `autoexit = FALSE`, use
+#' `daemons(NULL)` instead, which also sends exit signals to all connected
 #' daemons prior to resetting.
 #'
-#' For historical reasons, \code{daemons()} with no arguments (other than
-#' optionally \sQuote{.compute}) returns the value of \code{\link{status}}.
+#' For historical reasons, `daemons()` with no arguments (other than
+#' optionally `.compute`) returns the value of [status()].
 #'
 #' @inheritParams mirai
 #' @inheritParams dispatcher
 #' @param n integer number of daemons to launch.
-#' @param url [default NULL] if specified, a character string comprising a URL
+#' @param url \[default NULL\] if specified, a character string comprising a URL
 #'   at which to listen for remote daemons, including a port accepting incoming
 #'   connections, e.g. 'tcp://hostname:5555' or 'tcp://10.75.32.70:5555'.
 #'   Specify a URL with scheme 'tls+tcp://' to use secure TLS connections (for
 #'   details see Distributed Computing section below). Auxiliary function
-#'   \code{\link{host_url}} may be used to construct a valid host URL.
-#' @param remote [default NULL] required only for launching remote daemons, a
-#'   configuration generated by \code{\link{remote_config}} or
-#'   \code{\link{ssh_config}}.
-#' @param dispatcher [default TRUE] logical value, whether to use dispatcher.
+#'   [host_url()] may be used to construct a valid host URL.
+#' @param remote \[default NULL\] required only for launching remote daemons, a
+#'   configuration generated by [remote_config()] or [ssh_config()].
+#' @param dispatcher \[default TRUE\] logical value, whether to use dispatcher.
 #'   Dispatcher runs in a separate process to ensure optimal scheduling,
 #'   although this may not always be required (for details see Dispatcher
 #'   section below).
 #' @param ... (optional) additional arguments passed through to
-#'   \code{\link{daemon}} if launching daemons. These include \sQuote{asyncdial},
-#'   \sQuote{autoexit}, \sQuote{cleanup}, \sQuote{output}, \sQuote{maxtasks},
-#'   \sQuote{idletime} and \sQuote{walltime}.
-#' @param seed [default NULL] (optional) supply a random seed (single value,
+#'   [daemon()] if launching daemons. These include `asyncdial`, `autoexit`,
+#'   `cleanup`, `output`, `maxtasks`, `idletime` and `walltime`.
+#' @param seed \[default NULL\] (optional) supply a random seed (single value,
 #'   interpreted as an integer). This is used to inititalise the L'Ecuyer-CMRG
 #'   RNG streams sent to each daemon. Note that reproducible results can be
-#'   expected only for \code{dispatcher = 'none'}, as the unpredictable timing
-#'   of task completions would otherwise influence the tasks sent to each
-#'   daemon. Even for \code{dispatcher = 'none'}, reproducibility is not
-#'   guaranteed if the order in which tasks are sent is not deterministic.
-#' @param serial [default NULL] (optional, requires dispatcher) a configuration
-#'   created by \code{\link{serial_config}} to register serialization and
+#'   expected only for `dispatcher = FALSE`, as the unpredictable timing of task
+#'   completions would otherwise influence the tasks sent to each daemon. Even
+#'   for `dispatcher = FALSE`, reproducibility is not guaranteed if the order in
+#'   which tasks are sent is not deterministic.
+#' @param serial \[default NULL\] (optional, requires dispatcher) a
+#'   configuration created by [serial_config()] to register serialization and
 #'   unserialization functions for normally non-exportable reference objects,
 #'   such as Arrow Tables or torch tensors.
-#' @param tls [default NULL] (optional for secure TLS connections) if not
+#' @param tls \[default NULL\] (optional for secure TLS connections) if not
 #'   supplied, zero-configuration single-use keys and certificates are
-#'   automatically generated. If supplied, \strong{either} the character path to
+#'   automatically generated. If supplied, **either** the character path to
 #'   a file containing the PEM-encoded TLS certificate and associated private
 #'   key (may contain additional certificates leading to a validation chain,
-#'   with the TLS certificate first), \strong{or} a length 2 character vector
-#'   comprising [i] the TLS certificate (optionally certificate chain) and [ii]
-#'   the associated private key.
+#'   with the TLS certificate first), **or** a length 2 character vector
+#'   comprising \[i\] the TLS certificate (optionally certificate chain) and
+#'   \[ii\] the associated private key.
 #'
 #' @return The integer number of daemons launched locally (zero if specifying
-#'   \sQuote{url} / using a remote launcher).
+#'   `url` or using a remote launcher).
 #'
 #' @section Local Daemons:
 #'
 #' Daemons provide a potentially more efficient solution for asynchronous
-#' operations as new processes no longer need to be created on an \emph{ad hoc}
+#' operations as new processes no longer need to be created on an *ad hoc*
 #' basis.
 #'
-#' Supply the argument \sQuote{n} to set the number of daemons. New background
-#' \code{\link{daemon}} processes are automatically created on the local machine
+#' Supply the argument `n` to set the number of daemons. New background
+#' [daemon()] processes are automatically created on the local machine
 #' connecting back to the host process, either directly or via dispatcher.
 #'
 #' @section Dispatcher:
 #'
-#' By default \code{dispatcher = TRUE} launches a background process running
-#' \code{\link{dispatcher}}. Dispatcher connects to daemons on behalf of
-#' the host, queues tasks, and ensures optimal scheduling.
+#' By default `dispatcher = TRUE` launches a background process running
+#' [dispatcher()]. Dispatcher connects to daemons on behalf of the host, queues
+#' tasks, and ensures optimal scheduling.
 #'
-#' Specifying \code{dispatcher = FALSE}, daemons connect directly to the
-#' host and tasks are distributed in a round-robin fashion. As tasks are queued
-#' at each daemon, optimal scheduling is not guaranteed as the duration of each
-#' task cannot be known \emph{a priori}. Tasks can be queued at one daemon while
-#' others remain idle. However, this provides the most resource-light approach,
-#' suited to working with similar-length tasks, or where concurrent tasks
-#' typically do not exceed available daemons.
+#' Specifying `dispatcher = FALSE`, daemons connect directly to the host and
+#' tasks are distributed in a round-robin fashion. As tasks are queued at each
+#' daemon, optimal scheduling is not guaranteed as the duration of each task
+#' cannot be known *a priori*. Tasks can be queued at one daemon while others
+#' remain idle. However, this provides the most resource-light approach, suited
+#' to working with similar-length tasks, or where concurrent tasks typically do
+#' not exceed available daemons.
 #'
 #' @section Distributed Computing:
 #'
-#' Specifying \sQuote{url} as a character string allows tasks to be distributed
-#' across the network. \sQuote{n} is not required in this case, and disregarded
-#' if supplied.
+#' Specifying `url` as a character string allows tasks to be distributed across
+#' the network. `n` is only required in this case if providing a launch
+#' configuration to `remote` to launch remote daemons.
 #'
-#' Supply a URL with a \sQuote{tcp://} scheme, such as
-#' \sQuote{tcp://10.75.32.70:5555}. The host / dispatcher listens at this
-#' address, utilising a single port. Individual daemons (started with
-#' \code{\link{daemon}}) may then dial in to this URL. Host / dispatcher
-#' automatically adjusts to the number of daemons actually connected, allowing
-#' dynamic upscaling or downscaling as required.
+#' Supply a URL with a 'tcp://' scheme, such as 'tcp://10.75.32.70:5555'. The
+#' host / dispatcher listens at this address, utilising a single port.
+#' Individual daemons (started with [daemon()]) may then dial in to this URL.
+#' Host / dispatcher automatically adjusts to the number of daemons actually
+#' connected, allowing dynamic upscaling or downscaling as required.
 #'
-#' Switching the URL scheme to \sQuote{tls+tcp://} automatically upgrades the
-#' connection to use TLS. The auxiliary function \code{\link{host_url}} may be
-#' used to construct a valid host URL based on the computer's hostname.
+#' Switching the URL scheme to 'tls+tcp://' automatically upgrades the
+#' connection to use TLS. The auxiliary function [host_url()] may be used to
+#' construct a valid host URL based on the computer's hostname.
 #'
-#' IPv6 addresses are also supported and must be enclosed in square brackets [ ]
-#' to avoid confusion with the final colon separating the port. For example,
-#' port 5555 on the IPv6 loopback address ::1 would be specified as
-#' \sQuote{tcp://[::1]:5555}.
+#' IPv6 addresses are also supported and must be enclosed in square brackets
+#' `[]` to avoid confusion with the final colon separating the port. For
+#' example, port 5555 on the IPv6 loopback address ::1 would be specified as
+#' 'tcp://\[::1\]:5555'.
 #'
-#' Specifying the wildcard value zero for the port number e.g.
-#' \sQuote{tcp://[::1]:0} will automatically assign a free ephemeral port. Use
-#' \code{\link{status}} to inspect the actual assigned port at any time.
+#' Specifying the wildcard value zero for the port number e.g. 'tcp://\[::1\]:0'
+#' will automatically assign a free ephemeral port. Use [status()] to inspect
+#' the actual assigned port at any time.
 #'
-#' Specify \sQuote{remote} with a call to \code{\link{remote_config}} or
-#' \code{\link{ssh_config}} to launch daemons on remote machines. Otherwise,
-#' \code{\link{launch_remote}} may be used to generate the shell commands to
-#' deploy daemons manually on remote resources.
+#' Specify `remote` with a call to [remote_config()] or [ssh_config()] to launch
+#' daemons on remote machines. Otherwise, [launch_remote()] may be used to
+#' generate the shell commands to deploy daemons manually on remote resources.
 #'
 #' @section Compute Profiles:
 #'
-#' By default, the \sQuote{default} compute profile is used. Providing a
-#' character value for \sQuote{.compute} creates a new compute profile with the
-#' name specified. Each compute profile retains its own daemons settings, and
-#' may be operated independently of each other. Some usage examples follow:
+#' By default, the `"default"` compute profile is used. Providing a character
+#' value for `.compute` creates a new compute profile with the name specified.
+#' Each compute profile retains its own daemons settings, and may be operated
+#' independently of each other. Some usage examples follow:
 #'
-#' \strong{local / remote} daemons may be set with a host URL and specifying
-#' \sQuote{.compute} as \sQuote{remote}, which creates a new compute profile.
-#' Subsequent \code{\link{mirai}} calls may then be sent for local computation
-#' by not specifying the \sQuote{.compute} argument, or for remote computation
-#' to connected daemons by specifying the \sQuote{.compute} argument as
-#' \sQuote{remote}.
+#' **local / remote** daemons may be set with a host URL and specifying
+#' `.compute` as `"remote"`, which creates a new compute profile. Subsequent
+#' [mirai()] calls may then be sent for local computation by not specifying the
+#' `.compute` argument, or for remote computation to connected daemons by
+#' specifying the `.compute` argument as `"remote"`.
 #'
-#' \strong{cpu / gpu} some tasks may require access to different types of
-#' daemon, such as those with GPUs. In this case, \code{daemons()} may be called
-#' to set up host URLs for CPU-only daemons and for those with GPUs, specifying
-#' the \sQuote{.compute} argument as \sQuote{cpu} and \sQuote{gpu} respectively.
-#' By supplying the \sQuote{.compute} argument to subsequent \code{\link{mirai}}
-#' calls, tasks may be sent to either \sQuote{cpu} or \sQuote{gpu} daemons as
-#' appropriate.
+#' **cpu / gpu** some tasks may require access to different types of daemon,
+#' such as those with GPUs. In this case, `daemons()` may be called to set up
+#' host URLs for CPU-only daemons and for those with GPUs, specifying the
+#' `.compute` argument as `"cpu"` and `"gpu"` respectively. By supplying the
+#' `.compute` argument to subsequent [mirai()] calls, tasks may be sent to
+#' either `cpu` or `gpu` daemons as appropriate.
 #'
-#' Note: further actions such as resetting daemons via \code{daemons(0)} should
-#' be carried out with the desired \sQuote{.compute} argument specified.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#' Note: further actions such as resetting daemons via `daemons(0)` should
+#' be carried out with the desired `.compute` argument specified.
 #'
+#' @examplesIf interactive()
 #' # Create 2 local daemons (using dispatcher)
 #' daemons(2)
 #' status()
@@ -211,23 +202,21 @@
 #'   }
 #' )
 #'
-#' }
-#'
 #' \dontrun{
+#'
 #' # Launch daemons on remotes 'nodeone' and 'nodetwo' using SSH
 #' # connecting back directly to the host URL over a TLS connection:
+#' daemons(
+#'   url = host_url(tls = TRUE),
+#'   remote = ssh_config(c('ssh://nodeone', 'ssh://nodetwo'))
+#' )
 #'
-#' daemons(n = 1L,
-#'         url = host_url(tls = TRUE),
-#'         remote = ssh_config(c('ssh://nodeone', 'ssh://nodetwo')),
-#'         dispatcher = FALSE)
-#'
-#' # Launch 4 daemons on the remote machine 10.75.32.90 using SSH tunnelling
-#' # over port 5555 ('url' hostname must be '127.0.0.1'):
-#'
-#' daemons(n = 4L,
-#'         url = 'tcp://127.0.0.1:5555',
-#'         remote = ssh_config('ssh://10.75.32.90', tunnel = TRUE, port = 5555))
+#' # Launch 4 daemons on the remote machine 10.75.32.90 using SSH tunnelling:
+#' daemons(
+#'   n = 4,
+#'   url = local_url(tcp = TRUE),
+#'   remote = ssh_config('ssh://10.75.32.90', tunnel = TRUE)
+#' )
 #'
 #' }
 #'
@@ -237,6 +226,7 @@ daemons <- function(n, url = NULL, remote = NULL, dispatcher = TRUE, ...,
                     seed = NULL, serial = NULL, tls = NULL, pass = NULL,
                     .compute = "default") {
 
+  if (missing(.compute)) .compute <- .[["cp"]]
   missing(n) && missing(url) && return(status(.compute))
 
   envir <- ..[[.compute]]
@@ -268,8 +258,11 @@ daemons <- function(n, url = NULL, remote = NULL, dispatcher = TRUE, ...,
         stop(._[["dispatcher_args"]])
       )
       `[[<-`(.., .compute, `[[<-`(`[[<-`(`[[<-`(envir, "sock", sock), "n", launches), "dots", dots))
-      if (length(remote))
+      if (length(remote)) {
+        on.exit(daemons(0L, .compute = .compute))
         launch_remote(n = n, remote = remote, tls = envir[["tls"]], ..., .compute = .compute)
+        on.exit()
+      }
     } else {
       stop(sprintf(._[["daemons_set"]], .compute))
     }
@@ -336,19 +329,16 @@ print.miraiDaemons <- function(x, ...) print(unclass(x))
 #' their values collected) so that daemons are not reset before they have all
 #' completed.
 #'
-#' This function is an S3 method for the generic \code{with} for class
+#' This function is an S3 method for the generic [with()] for class
 #' 'miraiDaemons'.
 #'
-#' @param data a call to \code{\link{daemons}}.
+#' @param data a call to [daemons()].
 #' @param expr an expression to evaluate.
 #' @param ... not used.
 #'
-#' @return The return value of \sQuote{expr}.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#' @return The return value of `expr`.
 #'
+#' @examplesIf interactive()
 #' with(
 #'   daemons(2, dispatcher = FALSE),
 #'   {
@@ -360,13 +350,16 @@ print.miraiDaemons <- function(x, ...) print(unclass(x))
 #'
 #' status()
 #'
-#' }
-#'
 #' @export
 #'
 with.miraiDaemons <- function(data, expr, ...) {
 
-  on.exit(daemons(0L, .compute = class(data)[2L]))
+  prev_profile <- .[["cp"]]
+  `[[<-`(., "cp", class(data)[2L])
+  on.exit({
+    daemons(0L)
+    `[[<-`(., "cp", prev_profile)
+  })
   expr
 
 }
@@ -376,45 +369,41 @@ with.miraiDaemons <- function(data, expr, ...) {
 #' Retrieve status information for the specified compute profile, comprising
 #' current connections and daemons status.
 #'
-#' @param .compute [default 'default'] character compute profile (each compute
+#' @param .compute \[default 'default'\] character compute profile (each compute
 #'   profile has its own set of daemons for connecting to different resources).
 #'
-#'   \strong{or} a \sQuote{miraiCluster} to obtain its status.
+#'   **or** a 'miraiCluster' to obtain its status.
 #'
 #' @return A named list comprising:
 #'   \itemize{
-#'     \item \strong{connections} - integer number of active daemon connections.
-#'     \item \strong{daemons} - character URL at which host / dispatcher is
-#'     listening, or else \code{0L} if daemons have not yet been set.
-#'     \item \strong{mirai} (present only if using dispatcher) - a named integer
-#'     vector comprising: \strong{awaiting} - number of tasks queued for
-#'     execution at dispatcher, \strong{executing} - number of tasks sent to a
-#'     daemon for execution, and \strong{completed} - number of tasks for which
-#'     the result has been received (either completed or cancelled).
+#'     \item **connections** - integer number of active daemon connections.
+#'     \item **daemons** - character URL at which host / dispatcher is
+#'     listening, or else `0L` if daemons have not yet been set.
+#'     \item **mirai** (present only if using dispatcher) - a named integer
+#'     vector comprising: **awaiting** - number of tasks queued for execution at
+#'     dispatcher, **executing** - number of tasks sent to a daemon for
+#'     execution, and **completed** - number of tasks for which the result has
+#'     been received (either completed or cancelled).
 #'   }
 #'
 #' @section Events:
 #'
 #'   If dispatcher is used combined with daemon IDs, an additional element
-#'   \strong{events} will report the positive integer ID when the daemon
-#'   connects and the negative value when it disconnects. Only the events since
-#'   the previous status query are returned.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#'   **events** will report the positive integer ID when the daemon connects and
+#'   the negative value when it disconnects. Only the events since the previous
+#'   status query are returned.
 #'
+#' @examplesIf interactive()
 #' status()
 #' daemons(url = "tcp://[::1]:0")
 #' status()
 #' daemons(0)
 #'
-#' }
-#'
 #' @export
 #'
 status <- function(.compute = "default") {
 
+  if (missing(.compute)) .compute <- .[["cp"]]
   is.list(.compute) && return(status(attr(.compute, "id")))
   envir <- ..[[.compute]]
   is.null(envir) && return(list(connections = 0L, daemons = 0L))
@@ -433,21 +422,19 @@ status <- function(.compute = "default") {
 #' profile.
 #'
 #' @param class character string of the class of object custom serialization
-#'   functions are applied to, e.g. \sQuote{ArrowTabular} or
-#'   \sQuote{torch_tensor}.
+#'   functions are applied to, e.g. 'ArrowTabular' or 'torch_tensor'.
 #' @param sfunc a function that accepts a reference object inheriting from
-#'   \sQuote{class} (or a list of such objects) and returns a raw vector.
+#'   `class` (or a list of such objects) and returns a raw vector.
 #' @param ufunc a function that accepts a raw vector and returns a reference
 #'   object (or list of such objects).
-#' @param vec [default FALSE] whether or not the serialization functions are
+#' @param vec \[default FALSE\] whether or not the serialization functions are
 #'   vectorized. If FALSE, they should accept and return reference objects
-#'   individually e.g. \code{arrow::write_to_raw} and
-#'   \code{arrow::read_ipc_stream}. If TRUE, they should accept and return a
-#'   list of reference objects, e.g. \code{torch::torch_serialize} and
-#'   \code{torch::torch_load}.
+#'   individually e.g. `arrow::write_to_raw` and `arrow::read_ipc_stream`. If
+#'   TRUE, they should accept and return a list of reference objects, e.g.
+#'   `torch::torch_serialize` and `torch::torch_load`.
 #'
 #' @return A list comprising the configuration. This should be passed to the
-#'   \sQuote{serial} argument of \code{\link{daemons}}.
+#'   `serial` argument of [daemons()].
 #'
 #' @examples
 #' cfg <- serial_config("test_cls", function(x) serialize(x, NULL), unserialize)
