@@ -20,90 +20,81 @@
 #'
 #' Evaluate an expression asynchronously in a new background R process or
 #' persistent daemon (local or remote). This function will return immediately
-#' with a \sQuote{mirai}, which will resolve to the evaluated result once
-#' complete.
+#' with a 'mirai', which will resolve to the evaluated result once complete.
 #'
-#' This function will return a \sQuote{mirai} object immediately.
+#' This function will return a 'mirai' object immediately.
 #'
-#' The value of a mirai may be accessed at any time at \code{$data}, and if yet
-#' to resolve, an \sQuote{unresolved} logical NA will be returned instead.
+#' The value of a mirai may be accessed at any time at `$data`, and if yet
+#' to resolve, an 'unresolved' logical NA will be returned instead.
 #'
-#' \code{\link{unresolved}} may be used on a mirai, returning TRUE if a
-#' \sQuote{mirai} has yet to resolve and FALSE otherwise. This is suitable for
-#' use in control flow statements such as \code{while} or \code{if}.
+#' [unresolved()] may be used on a mirai, returning TRUE if a 'mirai' has yet to
+#' resolve and FALSE otherwise. This is suitable for use in control flow
+#' statements such as `while` or `if`.
 #'
-#' Alternatively, to call (and wait for) the result, use
-#' \code{\link{call_mirai}} on the returned \sQuote{mirai}. This will block
-#' until the result is returned.
+#' Alternatively, to call (and wait for) the result, use [call_mirai()] on the
+#' returned 'mirai'. This will block until the result is returned.
 #'
-#' Specify \sQuote{.compute} to send the mirai using a specific compute profile
-#' (if previously created by \code{\link{daemons}}), otherwise leave as
-#' \sQuote{default}.
+#' Specify `.compute` to send the mirai using a specific compute profile (if
+#' previously created by [daemons()]), otherwise leave as `"default"`.
 #'
 #' @param .expr an expression to evaluate asynchronously (of arbitrary length,
-#'   wrapped in \{ \} where necessary), \strong{or else} a pre-constructed
-#'   language object.
-#' @param ... (optional) \strong{either} named arguments (name = value pairs)
-#'   specifying objects referenced, but not defined, in \sQuote{.expr},
-#'   \strong{or} an environment containing such objects. See \sQuote{evaluation}
-#'   section below.
-#' @param .args (optional) \strong{either} a named list specifying objects
-#'   referenced, but not defined, in \sQuote{.expr}, \strong{or} an environment
-#'   containing such objects. These objects will remain local to the evaluation
-#'   environment as opposed to those supplied in \sQuote{...} above - see
-#'   \sQuote{evaluation} section below.
-#' @param .timeout [default NULL] for no timeout, or an integer value in
-#'   milliseconds. A mirai will resolve to an \sQuote{errorValue} 5 (timed out)
-#'   if evaluation exceeds this limit.
-#' @param .compute [default 'default'] character value for the compute profile
+#'   wrapped in \{ \} where necessary), **or else** a pre-constructed language
+#'   object.
+#' @param ... (optional) **either** named arguments (name = value pairs)
+#'   specifying objects referenced, but not defined, in `.expr`, **or** an
+#'   environment containing such objects. See 'evaluation' section below.
+#' @param .args (optional) **either** a named list specifying objects
+#'   referenced, but not defined, in `.expr`, **or** an environment containing
+#'   such objects. These objects will remain local to the evaluation environment
+#'   as opposed to those supplied in `...` above - see 'evaluation' section
+#'   below.
+#' @param .timeout \[default NULL\] for no timeout, or an integer value in
+#'   milliseconds. A mirai will resolve to an 'errorValue' 5 (timed out) if
+#'   evaluation exceeds this limit.
+#' @param .compute \[default 'default'\] character value for the compute profile
 #'   to use (each compute profile has its own independent set of daemons).
 #'
-#' @return A \sQuote{mirai} object.
+#' @return A 'mirai' object.
 #'
 #' @section Evaluation:
 #'
-#' The expression \sQuote{.expr} will be evaluated in a separate R process in a
-#' clean environment (not the global environment), consisting only of the
-#' objects supplied to \sQuote{.args}, with the objects passed as \sQuote{...}
-#' assigned to the global environment of that process.
+#' The expression `.expr` will be evaluated in a separate R process in a clean
+#' environment (not the global environment), consisting only of the objects
+#' supplied to `.args`, with the objects passed as `...` assigned to the global
+#' environment of that process.
 #'
 #' As evaluation occurs in a clean environment, all undefined objects must be
-#' supplied though \sQuote{...} and/or \sQuote{.args}, including self-defined
-#' functions. Functions from a package should use namespaced calls such as
-#' \code{mirai::mirai()}, or else the package should be loaded beforehand as
-#' part of \sQuote{.expr}.
+#' supplied through `...` and/or `.args`, including self-defined functions.
+#' Functions from a package should use namespaced calls such as
+#' `mirai::mirai()`, or else the package should be loaded beforehand as part of
+#' `.expr`.
 #'
-#' For evaluation to occur \emph{as if} in your global environment, supply
-#' objects to \sQuote{...} rather than \sQuote{.args}, e.g. for free variables
-#' or helper functions defined in function bodies, as scoping rules may
-#' otherwise prevent them from being found.
+#' For evaluation to occur *as if* in your global environment, supply objects to
+#' `...` rather than `.args`, e.g. for free variables or helper functions
+#' defined in function bodies, as scoping rules may otherwise prevent them from
+#' being found.
 #'
 #' @section Timeouts:
 #'
-#' Specifying the \sQuote{.timeout} argument ensures that the mirai always
-#' resolves. However, the task may not have completed and still be ongoing in
-#' the daemon process. Use \code{\link{stop_mirai}} instead to explicitly stop
-#' and interrupt a task.
+#' Specifying the `.timeout` argument ensures that the mirai always resolves.
+#' However, the task may not have completed and still be ongoing in the daemon
+#' process. Use [stop_mirai()] instead to explicitly stop and interrupt a task.
 #'
 #' @section Errors:
 #'
 #' If an error occurs in evaluation, the error message is returned as a
-#' character string of class \sQuote{miraiError} and \sQuote{errorValue}.
-#' \code{\link{is_mirai_error}} may be used to test for this. The elements of
-#' the original condition are accessible via \code{$} on the error object. A
-#' stack trace comprising a list of calls is also available at
-#' \code{$stack.trace}.
+#' character string of class 'miraiError' and 'errorValue'. [is_mirai_error()]
+#' may be used to test for this. The elements of the original condition are
+#' accessible via `$` on the error object. A stack trace comprising a list of
+#' calls is also available at `$stack.trace`.
 #'
 #' If a daemon crashes or terminates unexpectedly during evaluation, an
-#' \sQuote{errorValue} 19 (Connection reset) is returned.
+#' 'errorValue' 19 (Connection reset) is returned.
 #'
-#' \code{\link{is_error_value}} tests for all error conditions including
-#' \sQuote{mirai} errors, interrupts, and timeouts.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#' [is_error_value()] tests for all error conditions including 'mirai' errors,
+#' interrupts, and timeouts.
 #'
+#' @examplesIf interactive()
 #' # specifying objects via '...'
 #' n <- 3
 #' m <- mirai(x + y + 2, x = 2, y = n)
@@ -154,8 +145,6 @@
 #' m <- mirai(.expr = expr, .args = args)
 #' collect_mirai(m)
 #'
-#' }
-#'
 #' @export
 #'
 mirai <- function(.expr, ..., .args = list(), .timeout = NULL, .compute = "default") {
@@ -168,7 +157,8 @@ mirai <- function(.expr, ..., .args = list(), .timeout = NULL, .compute = "defau
     gn <- names(globals)
     if (is.null(gn)) {
       is.environment(globals[[1L]]) || stop(._[["named_dots"]])
-      globals <- as.list.environment(globals[[1L]])
+      globals <- as.list.environment(globals[[1L]], all.names = TRUE)
+      globals[[".Random.seed"]] <- NULL
     }
     all(nzchar(gn)) || stop(._[["named_dots"]])
   }
@@ -178,11 +168,12 @@ mirai <- function(.expr, ..., .args = list(), .timeout = NULL, .compute = "defau
   )
   if (length(.args)) {
     if (is.environment(.args))
-      .args <- as.list.environment(.args) else
+      .args <- as.list.environment(.args, all.names = TRUE) else
         length(names(.args)) && all(nzchar(names(.args))) || stop(._[["named_args"]])
     data <- c(.args, data)
   }
 
+  if (missing(.compute)) .compute <- .[["cp"]]
   envir <- ..[[.compute]]
   is.null(envir) && return(ephemeral_daemon(data, .timeout))
   r <- request(.context(envir[["sock"]]), data, send_mode = 1L, recv_mode = 1L, timeout = .timeout, cv = envir[["cv"]])
@@ -192,11 +183,11 @@ mirai <- function(.expr, ..., .args = list(), .timeout = NULL, .compute = "defau
 
 #' Evaluate Everywhere
 #'
-#' Evaluate an expression \sQuote{everywhere} on all connected daemons for the
+#' Evaluate an expression 'everywhere' on all connected daemons for the
 #' specified compute profile - this must be set prior to calling this function.
 #' Designed for performing setup operations across daemons by loading packages
 #' or exporting common data. Resultant changes to the global environment, loaded
-#' packages and options are persisted regardless of a daemon's \sQuote{cleanup}
+#' packages and options are persisted regardless of a daemon's `cleanup`
 #' setting.
 #'
 #' This function should be called when no other mirai operations are in
@@ -208,14 +199,11 @@ mirai <- function(.expr, ..., .args = list(), .timeout = NULL, .compute = "defau
 #' @inheritParams mirai
 #'
 #' @return A list of mirai executed on each daemon. This may be waited for and
-#'   inspected using \code{\link{call_mirai}} or \code{\link{collect_mirai}}.
+#'   inspected using [call_mirai()] or [collect_mirai()].
 #'
 #' @inheritSection mirai Evaluation
 #'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
-#'
+#' @examplesIf interactive()
 #' daemons(1)
 #' # export common data by a super-assignment expression:
 #' everywhere(y <<- 3)
@@ -238,12 +226,11 @@ mirai <- function(.expr, ..., .args = list(), .timeout = NULL, .compute = "defau
 #' m[]
 #' daemons(0)
 #'
-#' }
-#'
 #' @export
 #'
 everywhere <- function(.expr, ..., .args = list(), .compute = "default") {
 
+  if (missing(.compute)) .compute <- .[["cp"]]
   envir <- ..[[.compute]]
 
   is.null(envir) && stop(sprintf(._[["not_found"]], .compute))
@@ -271,40 +258,35 @@ everywhere <- function(.expr, ..., .args = list(), .compute = "default") {
 
 #' mirai (Call Value)
 #'
-#' \code{call_mirai} waits for the \sQuote{mirai} to resolve if still in
-#' progress, storing the value at \code{$data}, and returns the \sQuote{mirai}
-#' object.
+#' Waits for the 'mirai' to resolve if still in progress, stores the value at
+#' `$data`, and returns the 'mirai' object.
 #'
-#' Both functions accept a list of \sQuote{mirai} objects, such as that returned
-#' by \code{\link{mirai_map}} as well as individual \sQuote{mirai}.
+#' Accepts a list of 'mirai' objects, such as those returned by [mirai_map()],
+#' as well as individual 'mirai'.
 #'
-#' They will wait for the asynchronous operation(s) to complete if still in
-#' progress (blocking).
+#' Waits for the asynchronous operation(s) to complete if still in progress,
+#' blocking but user-interruptible.
 #'
-#' \code{x[]} may also be used to wait for and return the value of a mirai
-#' \code{x}, and is the equivalent of \code{call_mirai_(x)$data}.
+#' `x[]` may also be used to wait for and return the value of a mirai `x`, and
+#' is the equivalent of `call_mirai(x)$data`.
 #'
-#' @param x a \sQuote{mirai} object, or list of \sQuote{mirai} objects.
+#' @param x a 'mirai' object, or list of 'mirai' objects.
 #'
-#' @return The passed object (invisibly). For a \sQuote{mirai}, the retrieved
-#'   value is stored at \code{$data}.
+#' @return The passed object (invisibly). For a 'mirai', the retrieved value is
+#'   stored at `$data`.
 #'
 #' @section Alternatively:
 #'
-#' The value of a \sQuote{mirai} may be accessed at any time at \code{$data},
-#' and if yet to resolve, an \sQuote{unresolved} logical NA will be returned
-#' instead.
+#' The value of a 'mirai' may be accessed at any time at `$data`, and if yet to
+#' resolve, an 'unresolved' logical NA will be returned instead.
 #'
-#' Using \code{\link{unresolved}} on a \sQuote{mirai} returns TRUE only if it
-#' has yet to resolve and FALSE otherwise. This is suitable for use in control
-#' flow statements such as \code{while} or \code{if}.
+#' Using [unresolved()] on a 'mirai' returns TRUE only if it has yet to resolve
+#' and FALSE otherwise. This is suitable for use in control flow statements such
+#' as `while` or `if`.
 #'
 #' @inheritSection mirai Errors
 #'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
-#'
+#' @examplesIf interactive()
 #' # using call_mirai()
 #' df1 <- data.frame(a = 1, b = 2)
 #' df2 <- data.frame(a = 3, b = 1)
@@ -325,50 +307,33 @@ everywhere <- function(.expr, ..., .args = list(), .compute = "default") {
 #' }
 #' str(m$data)
 #'
-#' }
-#'
 #' @export
 #'
-call_mirai <- call_aio
-
-#' mirai (Call Value)
-#'
-#' \code{call_mirai_} is a variant of \code{call_mirai} that allows user
-#' interrupts, suitable for interactive use.
-#'
-#' @rdname call_mirai
-#' @export
-#'
-call_mirai_ <- call_aio_
+call_mirai <- call_aio_
 
 #' mirai (Collect Value)
 #'
-#' Waits for the \sQuote{mirai} to resolve if still in progress, and returns its
-#' value directly. It is a more efficient version of and equivalent to
-#' \code{call_mirai_(x)$data}.
+#' Waits for the 'mirai' to resolve if still in progress, and returns its value
+#' directly. It is a more efficient version of and equivalent to
+#' `call_mirai(x)$data`.
 #'
 #' This function will wait for the asynchronous operation(s) to complete if
 #' still in progress, blocking but interruptible.
 #'
-#' \code{x[]} may also be used to wait for and return the value of a mirai
-#' \code{x}, and is equivalent to \code{collect_mirai(x)}.
+#' `x[]` is an equivalent way to wait for and return the value of a mirai `x`.
 #'
 #' @inheritParams call_mirai
-#' @param options (if \sQuote{x} is a list of mirai) a character vector
-#'   comprising any combination of collection options for
-#'   \code{\link{mirai_map}}, such as \code{".flat"} or
-#'   \code{c(".progress", ".stop")}.
+#' @param options (if `x` is a list of mirai) a character vector comprising any
+#'   combination of collection options for [mirai_map()], such as `".flat"` or
+#'   `c(".progress", ".stop")`.
 #'
-#' @return An object (the return value of the \sQuote{mirai}), or a list of such
-#'   objects (the same length as \sQuote{x}, preserving names).
+#' @return An object (the return value of the 'mirai'), or a list of such
+#'   objects (the same length as `x`, preserving names).
 #'
 #' @inheritSection call_mirai Alternatively
 #' @inheritSection mirai Errors
 #'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
-#'
+#' @examplesIf interactive()
 #' # using collect_mirai()
 #' df1 <- data.frame(a = 1, b = 2)
 #' df2 <- data.frame(a = 3, b = 1)
@@ -384,8 +349,6 @@ call_mirai_ <- call_aio_
 #' collect_mirai(m, c(".flat", ".progress"))
 #' daemons(0)
 #'
-#' }
-#'
 #' @export
 #'
 collect_mirai <- function(x, options = NULL) {
@@ -400,13 +363,12 @@ collect_mirai <- function(x, options = NULL) {
 
 #' mirai (Stop)
 #'
-#' Stops a \sQuote{mirai} if still in progress, causing it to resolve
-#' immediately to an \sQuote{errorValue} 20 (Operation canceled).
+#' Stops a 'mirai' if still in progress, causing it to resolve immediately to an
+#' 'errorValue' 20 (Operation canceled).
 #'
-#' Using dispatcher allows cancellation of \sQuote{mirai}. In the case that the
-#' \sQuote{mirai} is awaiting execution, it is discarded from the queue and
-#' never evaluated. In the case it is already in execution, an interrupt will be
-#' sent.
+#' Using dispatcher allows cancellation of 'mirai'. In the case that the 'mirai'
+#' is awaiting execution, it is discarded from the queue and never evaluated. In
+#' the case it is already in execution, an interrupt will be sent.
 #'
 #' A successful cancellation request does not guarantee successful cancellation:
 #' the task, or a portion of it, may have already completed before the interrupt
@@ -416,24 +378,18 @@ collect_mirai <- function(x, options = NULL) {
 #'
 #' @inheritParams call_mirai
 #'
-#' @return Logical \code{TRUE} if the cancellation request was successful (was
-#'   awaiting execution or in execution), or else \code{FALSE} (if already
-#'   completed or previously cancelled). Will always return \code{FALSE} if not
-#'   using dispatcher.
+#' @return Logical TRUE if the cancellation request was successful (was awaiting
+#'   execution or in execution), or else FALSE (if already completed or
+#'   previously cancelled). Will always return FALSE if not using dispatcher.
 #'
-#'   Or a vector of logical values if supplying a list of \sQuote{mirai}, such
-#'   as those returned by \code{\link{mirai_map}}.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#'   **Or** a vector of logical values if supplying a list of 'mirai', such as
+#'   those returned by [mirai_map()].
 #'
+#' @examplesIf interactive()
 #' m <- mirai(Sys.sleep(n), n = 5)
 #' stop_mirai(m)
 #' m$data
 #'
-#' }
-#'
 #' @export
 #'
 stop_mirai <- function(x) {
@@ -453,51 +409,40 @@ stop_mirai <- function(x) {
 
 #' Query if a mirai is Unresolved
 #'
-#' Query whether a \sQuote{mirai}, \sQuote{mirai} value or list of
-#' \sQuote{mirai} remains unresolved. Unlike \code{\link{call_mirai}}, this
-#' function does not wait for completion.
+#' Query whether a 'mirai', 'mirai' value or list of 'mirai' remains unresolved.
+#' Unlike [call_mirai()], this function does not wait for completion.
 #'
-#' Suitable for use in control flow statements such as \code{while} or
-#' \code{if}.
+#' Suitable for use in control flow statements such as `while` or `if`.
 #'
-#' Note: querying resolution may cause a previously unresolved \sQuote{mirai} to
+#' Note: querying resolution may cause a previously unresolved 'mirai' to
 #' resolve.
 #'
-#' @param x a \sQuote{mirai} object or list of \sQuote{mirai} objects, or a
-#'   \sQuote{mirai} value stored at \code{$data}.
+#' @param x a 'mirai' object or list of 'mirai' objects, or a 'mirai' value
+#'   stored at `$data`.
 #'
-#' @return Logical TRUE if \sQuote{aio} is an unresolved \sQuote{mirai} or
-#'   \sQuote{mirai} value or the list contains at least one unresolved
-#'   \sQuote{mirai}, or FALSE otherwise.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#' @return Logical TRUE if `x` is an unresolved 'mirai' or 'mirai' value or the
+#'   list contains at least one unresolved 'mirai', or FALSE otherwise.
 #'
+#' @examplesIf interactive()
 #' m <- mirai(Sys.sleep(0.1))
 #' unresolved(m)
 #' Sys.sleep(0.3)
 #' unresolved(m)
 #'
-#' }
-#'
 #' @export
 #'
 unresolved <- unresolved
 
 #' Is mirai / mirai_map
 #'
-#' Is the object a \sQuote{mirai} or \sQuote{mirai_map}.
+#' Is the object a 'mirai' or 'mirai_map'.
 #'
 #' @param x an object.
 #'
-#' @return Logical TRUE if \sQuote{x} is of class \sQuote{mirai} or
-#'   \sQuote{mirai_map} respectively, FALSE otherwise.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#' @return Logical TRUE if `x` is of class 'mirai' or 'mirai_map' respectively,
+#'   FALSE otherwise.
 #'
+#' @examplesIf interactive()
 #' daemons(1, dispatcher = FALSE)
 #' df <- data.frame()
 #' m <- mirai(as.matrix(df), df = df)
@@ -509,8 +454,6 @@ unresolved <- unresolved
 #' is_mirai_map(mp[])
 #' daemons(0)
 #'
-#' }
-#'
 #' @export
 #'
 is_mirai <- function(x) inherits(x, "mirai")
@@ -524,28 +467,24 @@ is_mirai_map <- function(x) inherits(x, "mirai_map")
 #'
 #' Validator functions for error value types created by \pkg{mirai}.
 #'
-#' Is the object a \sQuote{miraiError}. When execution in a \sQuote{mirai}
-#' process fails, the error message is returned as a character string of class
-#' \sQuote{miraiError} and \sQuote{errorValue}. The elements of the original
-#' condition are accessible via \code{$} on the error object. A stack trace is
-#' also available at \code{$stack.trace}.
+#' Is the object a 'miraiError'. When execution in a 'mirai' process fails, the
+#' error message is returned as a character string of class 'miraiError' and
+#' 'errorValue'. The elements of the original condition are accessible via `$`
+#' on the error object. A stack trace is also available at `$stack.trace`.
 #'
-#' Is the object a \sQuote{miraiInterrupt}. When an ongoing \sQuote{mirai} is
-#' sent a user interrupt, it will resolve to an empty character string classed
-#' as \sQuote{miraiInterrupt} and \sQuote{errorValue}.
+#' Is the object a 'miraiInterrupt'. When an ongoing 'mirai' is sent a user
+#' interrupt, it will resolve to an empty character string classed as
+#' 'miraiInterrupt' and 'errorValue'.
 #'
-#' Is the object an \sQuote{errorValue}, such as a \sQuote{mirai} timeout, a
-#' \sQuote{miraiError} or a \sQuote{miraiInterrupt}. This is a catch-all
-#' condition that includes all returned error values.
+#' Is the object an 'errorValue', such as a 'mirai' timeout, a 'miraiError' or a
+#' 'miraiInterrupt'. This is a catch-all condition that includes all returned
+#' error values.
 #'
 #' @param x an object.
 #'
 #' @return Logical value TRUE or FALSE.
 #'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
-#'
+#' @examplesIf interactive()
 #' m <- mirai(stop())
 #' call_mirai(m)
 #' is_mirai_error(m$data)
@@ -559,8 +498,6 @@ is_mirai_map <- function(x) inherits(x, "mirai_map")
 #' is_mirai_interrupt(m2$data)
 #' is_error_value(m2$data)
 #'
-#' }
-#'
 #' @export
 #'
 is_mirai_error <- function(x) inherits(x, "miraiError")
@@ -632,17 +569,16 @@ deparse_safe <- function(x) if (length(x))
 
 mk_interrupt_error <- function() .miraiInterrupt
 
-mk_mirai_error <- function(e, sc) {
-  call <- deparse_safe(.subset2(e, "call"))
+mk_mirai_error <- function(cnd, sc) {
+  cnd[["call"]] <- `attributes<-`(.subset2(cnd, "call"), NULL)
+  call <- deparse_safe(.subset2(cnd, "call"))
   msg <- if (is.null(call) || call == "eval(._mirai_.[[\".expr\"]], envir = ._mirai_., enclos = .GlobalEnv)")
-    sprintf("Error: %s", .subset2(e, "message")) else
-      sprintf("Error in %s: %s", call, .subset2(e, "message"))
-  idx <- which(
-    as.logical(
-      lapply(
-        sc,
-        identical,
-        quote(eval(._mirai_.[[".expr"]], envir = ._mirai_., enclos = .GlobalEnv))
+    sprintf("Error: %s", .subset2(cnd, "message")) else
+      sprintf("Error in %s: %s", call, .subset2(cnd, "message"))
+  idx <- max(
+    which(
+      as.logical(
+        lapply(sc, `==`, "eval(._mirai_.[[\".expr\"]], envir = ._mirai_., enclos = .GlobalEnv)")
       )
     )
   )
@@ -650,7 +586,7 @@ mk_mirai_error <- function(e, sc) {
   if (sc[[1L]][[1L]] == ".handleSimpleError")
     sc <- sc[-1L]
   sc <- lapply(sc, `attributes<-`, NULL)
-  out <- `attributes<-`(msg, `[[<-`(e, "stack.trace", sc))
+  out <- `attributes<-`(msg, `[[<-`(cnd, "stack.trace", sc))
   `class<-`(out, c("miraiError", "errorValue", "try-error"))
 }
 
