@@ -1,4 +1,4 @@
-# Copyright (C) 2023-2024 Hibiki AI Limited <info@hibiki-ai.com>
+# Copyright (C) 2023-2025 Hibiki AI Limited <info@hibiki-ai.com>
 #
 # This file is part of mirai.
 #
@@ -18,28 +18,25 @@
 
 #' Next >> Developer Interface
 #'
-#' \code{nextstream} retrieves the currently stored L'Ecuyer-CMRG RNG stream
+#' `nextstream` retrieves the currently stored L'Ecuyer-CMRG RNG stream
 #' for the specified compute profile and advances it to the next stream.
 #'
 #' These functions are exported for use by packages extending \pkg{mirai} with
-#' alternative launchers of \code{\link{daemon}} processes.
+#' alternative launchers of [daemon()] processes.
 #'
-#' For \code{nextstream}: This function should be called for its return value
+#' For `nextstream`: This function should be called for its return value
 #' when required. The function also has the side effect of automatically
 #' advancing the stream stored within the compute profile. This ensures that the
 #' next recursive stream is returned when the function is called again.
 #'
 #' @inheritParams mirai
 #'
-#' @return For \code{nextstream}: a length 7 integer vector, as given by
-#'   \code{.Random.seed} when the L'Ecuyer-CMRG RNG is in use (may be passed
-#'   directly to the \sQuote{rs} argument of \code{\link{daemon}}), or else
-#'   NULL if a stream has not yet been created.
-#'
-#' @examples
-#' if (interactive()) {
-#' # Only run examples in interactive R sessions
+#' @return For `nextstream`: a length 7 integer vector, as given by
+#'   `.Random.seed` when the L'Ecuyer-CMRG RNG is in use (may be passed directly
+#'   to the `rs` argument of [daemon()]), or else NULL if a stream has not yet
+#'   been created.
 #'
+#' @examplesIf interactive()
 #' daemons(1L)
 #' nextstream()
 #' nextstream()
@@ -49,8 +46,6 @@
 #'
 #' daemons(0)
 #'
-#' }
-#'
 #' @keywords internal
 #' @export
 #'
@@ -58,15 +53,14 @@ nextstream <- function(.compute = "default") next_stream(..[[.compute]])
 
 #' Next >> Developer Interface
 #'
-#' \code{nextget} retrieves the specified item from the specified compute
-#' profile.
+#' `nextget` retrieves the specified item from the specified compute profile.
 #'
-#' @param x character value of item to retrieve. One of \sQuote{n} (number of
-#'   dispatcher daemons), \sQuote{pid} (dispatcher process ID), \sQuote{urls}
-#'   (URLs dispatcher is listening at) or \sQuote{tls} (the stored client TLS
-#'   configuration for use by daemons).
+#' @param x character value of item to retrieve. One of `"n"` (number of
+#'   dispatcher daemons), `"pid"` (dispatcher process ID), `"urls"` (URLs
+#'   dispatcher is listening at) or `"tls"` (the stored client TLS configuration
+#'   for use by daemons).
 #'
-#' @return For \code{nextget}: the requested item, or else NULL if not present.
+#' @return For `nextget`: the requested item, or else NULL if not present.
 #'
 #' @keywords internal
 #' @rdname nextstream
@@ -76,13 +70,12 @@ nextget <- function(x, .compute = "default") ..[[.compute]][[x]]
 
 #' Next >> Developer Interface
 #'
-#' \code{nextcode} translates integer exit codes returned by
-#' \code{\link{daemon}}.
+#' `nextcode` translates integer exit codes returned by [daemon()].
 #'
-#' @param xc integer value.
+#' @param xc integer return value of [daemon()].
+#'
+#' @return For `nextcode`: character string.
 #'
-#' @return For \code{nextcode}: character string.
-#' 
 #' @examples
 #' nextcode(0L)
 #' nextcode(1L)
@@ -91,16 +84,8 @@ nextget <- function(x, .compute = "default") ..[[.compute]][[x]]
 #' @rdname nextstream
 #' @export
 #'
-nextcode <- function(xc) {
-  str <- switch(xc + 1L,
-    "0 | Daemon connection terminated",
-    "1 | Daemon idletime limit reached",
-    "2 | Daemon walltime limit reached",
-    "3 | Daemon task limit reached"
-  )
-  is.null(str) && return("")
-  str
-} 
+nextcode <- function(xc)
+  sprintf("%d | Daemon %s", xc, switch(xc + 1L, "connection terminated", "idletime limit reached", "walltime limit reached", "task limit reached"))
 
 # internals --------------------------------------------------------------------
 
